CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
83 lines
2.6 KiB
Plaintext
83 lines
2.6 KiB
Plaintext
// Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
//
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
// [sphinx-start]
|
|
#include <hip/hip_runtime.h>
|
|
|
|
#include <cstddef>
|
|
#include <cstdlib>
|
|
#include <iostream>
|
|
|
|
#define HIP_CHECK(expression) \
|
|
{ \
|
|
const hipError_t status = expression; \
|
|
if (status != hipSuccess) \
|
|
{ \
|
|
std::cerr << "HIP error " << status \
|
|
<< ": " << hipGetErrorString(status) \
|
|
<< " at " << __FILE__ << ":" \
|
|
<< __LINE__ << std::endl; \
|
|
std::exit(EXIT_FAILURE); \
|
|
} \
|
|
}
|
|
|
|
__global__ void simpleKernel(double *data, std::size_t elems)
|
|
{
|
|
int idx = blockIdx.x * blockDim.x + threadIdx.x;
|
|
if(idx < elems)
|
|
data[idx] = idx * 2.0;
|
|
}
|
|
|
|
int main()
|
|
{
|
|
int deviceCount;
|
|
HIP_CHECK(hipGetDeviceCount(&deviceCount));
|
|
if(deviceCount < 2)
|
|
{
|
|
std::cout << "This example requires at least two HIP devices." << std::endl;
|
|
return EXIT_SUCCESS;
|
|
}
|
|
|
|
double* deviceData0;
|
|
double* deviceData1;
|
|
constexpr std::size_t elems = 1024;
|
|
constexpr std::size_t size = elems * sizeof(double);
|
|
|
|
int deviceId0 = 0;
|
|
int deviceId1 = 1;
|
|
|
|
// Set device 0 and perform operations
|
|
HIP_CHECK(hipSetDevice(deviceId0)); // Set device 0 as current
|
|
HIP_CHECK(hipMalloc(&deviceData0, size)); // Allocate memory on device 0
|
|
simpleKernel<<<8, 128>>>(deviceData0, elems); // Launch kernel on device 0
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
// Set device 1 and perform operations
|
|
HIP_CHECK(hipSetDevice(deviceId1)); // Set device 1 as current
|
|
HIP_CHECK(hipMalloc(&deviceData1, size)); // Allocate memory on device 1
|
|
simpleKernel<<<8, 128>>>(deviceData1, elems); // Launch kernel on device 1
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
// Copy result from device 0
|
|
double hostData0[elems];
|
|
HIP_CHECK(hipSetDevice(deviceId0));
|
|
HIP_CHECK(hipMemcpy(hostData0, deviceData0, size, hipMemcpyDeviceToHost));
|
|
|
|
// Copy result from device 1
|
|
double hostData1[elems];
|
|
HIP_CHECK(hipSetDevice(deviceId1));
|
|
HIP_CHECK(hipMemcpy(hostData1, deviceData1, size, hipMemcpyDeviceToHost));
|
|
|
|
// Display results from both devices
|
|
std::cout << "Device 0 data: " << hostData0[0] << std::endl;
|
|
std::cout << "Device 1 data: " << hostData1[0] << std::endl;
|
|
|
|
// Free device memory
|
|
HIP_CHECK(hipFree(deviceData0));
|
|
HIP_CHECK(hipFree(deviceData1));
|
|
|
|
return EXIT_SUCCESS;
|
|
}
|
|
// [sphinx-end]
|